@@ -2,7 +2,6 @@
 package com.openexchange.spamsettings.generic;
 
 import java.util.Map;
-import org.json.JSONException;
 import org.json.JSONObject;
 import com.openexchange.datatypes.genericonf.DynamicFormDescription;
 import com.openexchange.datatypes.genericonf.json.FormContentParser;
@@ -18,10 +17,10 @@ import com.openexchange.tools.session.ServerSession;
  */
 public class SpamSettingsParser {
 
-    public Map<String, Object> parse(final ServerSession session, final JSONObject json) throws JSONException, OXException {
-        final FormContentParser formContentParser = new FormContentParser();
+    public Map<String, Object> parse(final ServerSession session, final JSONObject json) throws OXException {
+        // final FormContentParser formContentParser = new FormContentParser();
         final SpamSettingService service = SpamSettingsServiceRegistry.getServiceRegistry().getService(SpamSettingService.class);
         final DynamicFormDescription formDescription = service.getFormDescription(session);
-        return formContentParser.parse(json, formDescription);
+        return FormContentParser.parse(json, formDescription);
     }
 }
